CacheTier

Struct CacheTier 

pub struct CacheTier<K, V, P: EvictionPolicy = DefaultEvictionPolicy, const CAPACITY: usize = 0, const WAYS: usize = 8> { /* private fields */ }
Represents a single cache tier (e.g., T0, T1, T2) using Set-Associative Lock-Free arrays.

Implementations

Source

impl<K, V, P: EvictionPolicy, const CAPACITY: usize, const WAYS: usize> CacheTier<K, V, P, CAPACITY, WAYS>

pub const fn new(policy: P) -> Self

Create a new CacheTier.

pub fn get_set(&self, hash: usize) -> &[Slot<K, V>]

Retrieve the set of slots for a given hash.

pub fn fetch_hint<const N: usize>( &self, hash: usize, arena: &Arena<K, V, N>, guard: &Guard, ) -> Option<(K, V)>
where K: Clone, V: Clone,

Touch a slot by hash to prevent it from being evicted (Prefetch hint)

pub fn get_slot<const N: usize>( &self, arena: &Arena<K, V, N>, hash: usize, key: &K, guard: &Guard, ) -> Option<&Slot<K, V>>
where K: PartialEq,

Retrieve a slot if the key exists in this tier.

pub fn insert<const N: usize>( &self, arena: &Arena<K, V, N>, hash: usize, key: K, value: V, node: *mut ThreadStateNode, )
where K: PartialEq,

Insert a key and value into the tier using the provided eviction policy.