pub struct Guard { /* private fields */ }Expand description
A guard that pins the current thread to an epoch.
Implementations
Sourceimpl Guard
impl Guard
Sourcepub fn new(node: *mut ThreadStateNode) -> Self
pub fn new(node: *mut ThreadStateNode) -> Self
Create a new Guard using the explicitly provided ThreadStateNode.
pub unsafe fn unpinned(node: *mut ThreadStateNode) -> Self
pub unsafe fn dummy() -> Self
Sourcepub fn node(&self) -> *mut ThreadStateNode
pub fn node(&self) -> *mut ThreadStateNode
Get the underlying ThreadStateNode pointer.