DualCacheFF

Struct DualCacheFF 

pub struct DualCacheFF<K, V, P, const CAP2: usize, const CAP1: usize, const CAP0: usize, const TOTAL_CAP: usize, const MAX_THREADS: usize, const TLS_CAP: usize, const TLS_INDEX_CAP: usize>
where P: CachePolicy + Send + Sync,
{ pub daemon_mode: AtomicBool, pub cata_mode: AtomicBool, pub tls_registry: TlsRegistry<K, V, MAX_THREADS, TLS_CAP, TLS_INDEX_CAP>, pub global_tx: RwLock<Option<Arc<BoundedQueue<DaemonMessage<K, V>, 65536>>>>, pub daemon_handle: RwLock<Option<Daemon>>, /* private fields */ }
DualCacheFF is the main entry point for the cache, providing standard API operations and managing the background daemon for garbage collection and memory reclamation.

Fields

daemon_mode: AtomicBoolcata_mode: AtomicBooltls_registry: TlsRegistry<K, V, MAX_THREADS, TLS_CAP, TLS_INDEX_CAP>global_tx: RwLock<Option<Arc<BoundedQueue<DaemonMessage<K, V>, 65536>>>>daemon_handle: RwLock<Option<Daemon>>

Implementations

Source

impl<K, V, P, const CAP2: usize, const CAP1: usize, const CAP0: usize, const TOTAL_CAP: usize, const MAX_THREADS: usize, const TLS_CAP: usize, const TLS_INDEX_CAP: usize> DualCacheFF<K, V, P, CAP2, CAP1, CAP0, TOTAL_CAP, MAX_THREADS, TLS_CAP, TLS_INDEX_CAP>
where K: Clone + Eq + Hash + Send + Sync + 'static, V: Clone + Send + Sync + 'static, P: CachePolicy + Send + Sync + 'static,

pub const fn new(eviction: P::Evict) -> Self

pub fn set_cata_tuning(&'static self, on: bool)

Start the CATA-DC Demiurge tuning engine in the background

pub fn set_daemon_mode(&'static self, on: bool)

Turn the Daemon on or off. If turned on, a new daemon thread is automatically spawned and channel is established.

pub fn register_thread(&self) -> TlsHandle

Register the current thread to get a fast TLS handle.

pub fn get(&self, key: &K, handle: &TlsHandle) -> Option<V>

pub fn insert(&self, key: K, value: V, handle: &TlsHandle)

pub fn warmup(&self, key: K, value: V, handle: &TlsHandle)

Insert a key-value pair directly as a high-priority “genius” item. This bypasses normal promotion and pins the item directly in the hottest tier (T0). Equivalent to ‘insert_t1’ or ‘warmup’ from v0.4.0.

Source

impl<K, V, P, const CAP2: usize, const CAP1: usize, const CAP0: usize, const TOTAL_CAP: usize, const MAX_THREADS: usize, const TLS_CAP: usize, const TLS_INDEX_CAP: usize> DualCacheFF<K, V, P, CAP2, CAP1, CAP0, TOTAL_CAP, MAX_THREADS, TLS_CAP, TLS_INDEX_CAP>
where K: Clone + Eq, V: Clone, P: CachePolicy + Send + Sync,

pub fn get_metrics(&self) -> (u64, u64)