pub struct CacheTier<K, V, P: EvictionPolicy = DefaultEvictionPolicy, const CAPACITY: usize = 0, const WAYS: usize = 8> { /* private fields */ }Expand description
Represents a single cache tier (e.g., T0, T1, T2) using Set-Associative Lock-Free arrays.
Implementations
Sourceimpl<K, V, P: EvictionPolicy, const CAPACITY: usize, const WAYS: usize> CacheTier<K, V, P, CAPACITY, WAYS>
impl<K, V, P: EvictionPolicy, const CAPACITY: usize, const WAYS: usize> CacheTier<K, V, P, CAPACITY, WAYS>
Sourcepub fn get_set(&self, hash: usize) -> &[Slot<K, V>]
pub fn get_set(&self, hash: usize) -> &[Slot<K, V>]
Retrieve the set of slots for a given hash.
Sourcepub fn fetch_hint<const N: usize>(
&self,
hash: usize,
arena: &Arena<K, V, N>,
guard: &Guard,
) -> Option<(K, V)>
pub fn fetch_hint<const N: usize>( &self, hash: usize, arena: &Arena<K, V, N>, guard: &Guard, ) -> Option<(K, V)>
Touch a slot by hash to prevent it from being evicted (Prefetch hint)